# AffiliationGroupV30Rc2EducationSummaryV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30Rc2**](LastModifiedDateV30Rc2.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30Rc2**](ExternalIDsV30Rc2.md) |  | [optional] 
**summaries** | [**list[EducationSummaryV30Rc2]**](EducationSummaryV30Rc2.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

